
Plugins
=======

.. image:: /_static/plugins-diagram.*
   :alt: rdflib plugin "architecture"
   :width: 450px
   :target: _static/plugins-diagram.svg


Many parts of RDFLib are extensible with plugins through `setuptools entry-points <http://pythonhosted.org/distribute/setuptools.html#dynamic-discovery-of-services-and-plugins>`_. These pages list the plugins included in RDFLib core.  



.. toctree::
   :maxdepth: 1

   plugin_parsers
   plugin_serializers
   plugin_stores
   plugin_query_results   
